@@ -5,7 +5,9 @@ pub enum ErrorCode {
     #[msg("Token account not owned by the claim approver")]
     InvalidPaymentTokenAccount,
     #[msg("Token account not owned by the issuer")]
-    InvalidIssuerTokenAccount,
+    InvalidTokenAccount,
+    #[msg("User is not permitted to use")]
+    InvalidUser,
     #[msg("Invalid token manager for this claim approver")]
     InvalidTokenManager,
     #[msg("Usages at the maximum")]
